katsdpsigproc.rfi.test package
==============================

Submodules
----------

katsdpsigproc.rfi.test.test_background module
---------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_background
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.rfi.test.test_flagger module
------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_flagger
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.rfi.test.test_noise_est module
--------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_noise_est
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.rfi.test.test_threshold module
--------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_threshold
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.rfi.test.test_twodflag module
-------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_twodflag
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: katsdpsigproc.rfi.test
    :members:
    :undoc-members:
    :show-inheritance:
